@@ -289,10 +289,13 @@ class JSON2EDCLineageFiles:
         :param attribute:
         :return:
         """
+        print("looking for attribute >%s<" % attribute)
         for entity in entities:
             entity_attributes = self.get_attributes(entity)
+            print("Entity >%s< #attributes >%d<" % (entity, len(entity_attributes)))
             for entity_attribute in entity_attributes:
                 if entity_attribute["uid"] == attribute:
+                    print("Found: entity_attribute >%s< is named >%s<" % (entity_attribute["uid"], entity_attribute["name"]))
                     return True, entity, entity_attribute["name"]
         return False, None, None
 
@@ -341,7 +344,8 @@ class JSON2EDCLineageFiles:
     def get_target_entities(self, entity_assoc_id):
         targets = []
         for source_target_entity_link in entity_assoc_id["source_target_entity_links"]:
-            targets.append(source_target_entity_link["to"])
+            if source_target_entity_link["to"] not in targets:
+                targets.append(source_target_entity_link["to"])
         return targets
 
     def write_lineage_entry(self, entry):
